@@ -9,7 +9,8 @@
 //  Module:         Multithreaded AFF (AAFF = Advanced AFF)
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -27,8 +28,8 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#ifndef __AAFF_H__
-#define __AAFF_H__
+#ifndef AAFF_H
+#define AAFF_H
 
 #include "hash.h"
 
@@ -36,9 +37,9 @@ typedef struct _t_Aaff *t_pAaff;
 
 typedef struct
 {
-   bool Zero;         // Tells AaffWrite that all data is 0
-   bool Compressed;   // Tells AaffWrite whether the data should be written compressed or uncompressed
-   int  DataLenOut;   // If Compressed is true: The size of the compressed data
+   bool  Zero;         // Tells AaffWrite that all data is 0
+   bool  Compressed;   // Tells AaffWrite whether the data should be written compressed or uncompressed
+   uint  DataLenOut;   // If Compressed is true: The size of the compressed data
 } t_AaffPreprocess, *t_pAaffPreprocess;
 
 #define AAFF_SEGNAME_COMMAND_LINE "acquisition_commandline"
