@@ -11,7 +11,8 @@
 //                  window.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -114,6 +115,7 @@ QString t_Device::GetErrorText (void) const
    {
       case t_Error::UserRequest           : Text = t_MainWindow::tr("Aborted by user");           break;
       case t_Error::AcquisitionStartFailed: Text = t_MainWindow::tr("Acquisition start failure"); break;
+      case t_Error::DeviceMovedOnLaunch   : Text = t_MainWindow::tr("Device (re)moved");          break;
       case t_Error::ReadError             : Text = t_MainWindow::tr("Device read error");         break;
       case t_Error::TooManyBadSectors     : Text = t_MainWindow::tr("Too many bad sectors");      break;
       case t_Error::DisconnectTimeout     : Text = t_MainWindow::tr("Disconnect timeout");        break;
@@ -192,9 +194,9 @@ void t_Device::Initialise (void)
    this->AbortCount           = 0;
    this->DeleteAfterAbort     = false;
    this->Duplicate            = false;
-   this->pFifoMemory          = NULL;
-   this->pFifoRead            = NULL;
-   this->pThreadRead          = NULL;
+   this->pFifoMemory          = nullptr;
+   this->pFifoRead            = nullptr;
+   this->pThreadRead          = nullptr;
    this->FileDescSrc          = t_Device::FileDescEmpty;
 //   this->CurrentReadPos
 //   this->BadSectors
@@ -204,15 +206,15 @@ void t_Device::Initialise (void)
    this->StartTimestampVerify = QDateTime();
    this->StopTimestamp        = QDateTime();
 
-   this->pThreadWrite1        = NULL;
-   this->pThreadWrite2        = NULL;
+   this->pThreadWrite1        = nullptr;
+   this->pThreadWrite2        = nullptr;
 //   this->CurrentVerifyPosSrc
-   this->pFifoWrite1          = NULL;
-   this->pFifoWrite2          = NULL;
+   this->pFifoWrite1          = nullptr;
+   this->pFifoWrite2          = nullptr;
 
-   this->pThreadHash          = NULL;
-   this->pFifoHashIn          = NULL;
-   this->pFifoHashOut         = NULL;
+   this->pThreadHash          = nullptr;
+   this->pFifoHashIn          = nullptr;
+   this->pFifoHashOut         = nullptr;
    memset (&this->MD5Digest            , 0, sizeof(this->MD5Digest            ));
    memset (&this->MD5DigestVerifySrc   , 0, sizeof(this->MD5DigestVerifySrc   ));
    memset (&this->SHA1Digest           , 0, sizeof(this->SHA1Digest           ));
@@ -221,8 +223,8 @@ void t_Device::Initialise (void)
    memset (&this->SHA256DigestVerifySrc, 0, sizeof(this->SHA256DigestVerifySrc));
 // this->ImageFileHashes
 
-   this->pFifoCompressIn      = NULL;
-   this->pFifoCompressOut     = NULL;
+   this->pFifoCompressIn      = nullptr;
+   this->pFifoCompressOut     = nullptr;
    this->FifoMaxBlocks        = 0;
    this->FifoBlockSize        = 0;
 
@@ -261,8 +263,8 @@ void t_Device::InitialiseDeviceSpecific (const QString &SerialNumber, const QStr
    #warning "Debug code for device size faking still enabled"
       // this->Size = GETMIN ( 10*1024, Size);               // 10K
       // this->Size = GETMIN ( 20971520ULL, Size);           // 20 MiB
-       this->Size = GETMIN ( 1024*1024*1024ULL, Size);     //  1 GB
-      // this->Size = GETMIN (10737418240ULL, Size);         // 10 GiB
+      // this->Size = GETMIN ( 1024*1024*1024ULL, Size);     //  1 GB
+       this->Size = GETMIN (32*1024*1024*1024ULL, Size);         // 32 GiB
       // this->Size = 3ULL*1024ULL*1024ULL*1024ULL*1024ULL;  //  3 TB
       printf ("\nSize of %s set to %llu bytes", QSTR_TO_PSZ(this->LinuxDevice), this->Size);
    #endif
@@ -329,7 +331,7 @@ bool t_Device::DisconnectTimeoutReached() const
    if (CONFIG(LimitJobs) != CONFIG_LIMITJOBS_OFF)
    {
       if ((GetState() == t_Device::AcquirePaused) && (DisconnectTime > 0))
-         Reached = (time(NULL)-DisconnectTime) >= CONFIG(JobDisconnectTimeout);
+         Reached = (time(nullptr)-DisconnectTime) >= CONFIG(JobDisconnectTimeout);
    }
    return Reached;
 }
@@ -414,6 +416,8 @@ QVariant t_Device::GetState (t_pDevice pDevice)
                           break;
       case Queued       : StrState = t_MainWindow::tr("Queued");
                           break;
+      case Launch:
+      case LaunchPaused :
       case Acquire      :
       case Verify       : if (pDevice->Error.Abort())
                           {
@@ -421,9 +425,13 @@ QVariant t_Device::GetState (t_pDevice pDevice)
                           }
                           else
                           {
-                             if (pDevice->State == Acquire)
-                                  StrState = t_MainWindow::tr("Running");
-                             else StrState = t_MainWindow::tr("Verifying");
+                             switch (pDevice->State)
+                             {
+                                case LaunchPaused: StrState = t_MainWindow::tr("Launched, device disconnected" ); break;
+                                case Launch:       StrState = t_MainWindow::tr("Launched" ); break;
+                                case Acquire:      StrState = t_MainWindow::tr("Running"  ); break;
+                                default:           StrState = t_MainWindow::tr("Verifying");
+                             }
                              if (pDevice->Duplicate)
                              {
                                 if (pDevice->Error.Get(1) != t_Device::t_Error::None) StrState += " - image 1 failed, continuing with image 2";
@@ -598,7 +606,7 @@ QVariant t_Device::GetBadSectorCount (t_pDevice pDevice)
    else return "";
 }
 
-static void DeviceGetProgress (t_pDevice pDevice, quint64 *pCurrent=NULL, quint64 *pTotal=NULL)
+static void DeviceGetProgress (t_pDevice pDevice, quint64 *pCurrent=nullptr, quint64 *pTotal=nullptr)
 {
    quint64 Current, Total;
    bool    HasVerifications;
@@ -669,8 +677,9 @@ QVariant t_Device::GetCurrentSpeed (t_pDevice pDevice)
    int     MilliSeconds;
    quint64 CurrentPos;
 
-   if ((pDevice->State == Acquire) ||  // Don't display anything if no acquisition is running
-       (pDevice->State == Verify ))
+   if ((pDevice->State == Acquire)||  // Don't display anything if no acquisition is running
+       (pDevice->State == Launch) ||
+       (pDevice->State == Verify))
    {
       Now = QTime::currentTime();
       DeviceGetProgress (pDevice, &CurrentPos);
@@ -707,6 +716,9 @@ QVariant t_Device::GetAverageSpeed (t_pDevice pDevice)
         Seconds = pDevice->StartTimestamp.secsTo (QDateTime::currentDateTime());
    else Seconds = pDevice->StartTimestamp.secsTo (pDevice->StopTimestamp);
 
+   if (Seconds == 0)
+      return QString();
+
    if ((pDevice->StopTimestamp.isNull()) && (Seconds < DEVICE_MIN_RUNNING_SECONDS))
       return "--";
 
@@ -727,7 +739,8 @@ QVariant t_Device::GetRemaining (t_pDevice pDevice)
    quint64      Current, Total;
 
    if (!pDevice->Error.Abort() && ((pDevice->State == Acquire) || // Don't display anything if no acquisition is running
-                                   (pDevice->State == Verify )))
+                                   (pDevice->State == Launch)  ||
+                                   (pDevice->State == Verify)))
    {
       time (&Now);
       TotalSeconds = pDevice->StartTimestamp.secsTo (QDateTime::currentDateTime());
@@ -762,17 +775,18 @@ QVariant t_Device::GetFifoStatus (t_pDevice pDevice)
    QString Result;
 
    if ((pDevice->State == Acquire) ||  // Don't display anything if no acquisition is running
-       (pDevice->State == Verify ))
+       (pDevice->State == Launch)  ||
+       (pDevice->State == Verify))
    {
       int FifoUsageWrite = 0;                                    // The write thread gets a lot of dummy blocks into its Fifo (from SlotThreadCompressFinished), but
-                                                                 // only 1 of them is taken out (then, the write already exits its loop). If image verification is on
+                                                                 // only 1 of them is taken out (then, the write thread already exits its loop). If image verification is on
       if (pDevice->State != Verify)                              // then these dummy blocks remain the in the write fifo, leading to an ugly fifo usage display on the
       {                                                          // GUI. As I do not like to add code for remove dummy blocks (and waiting until they all have been
-         FifoUsageWrite = DeviceFifoUsage(pDevice->pFifoWrite1);
+         FifoUsageWrite = DeviceFifoUsage(pDevice->pFifoWrite1); // received etc.) I decided to zero them artificially here.
          if (pDevice->Duplicate)
             FifoUsageWrite = (FifoUsageWrite + DeviceFifoUsage(pDevice->pFifoWrite2)) / 2;
       }
-                                                                // received etc.) I decided to zero them artificially here.
+
       if (!pDevice->HasHashThread() && !pDevice->HasCompressionThreads())
       {
          Result = QString ("r %1 w") .arg (FifoUsageWrite);
@@ -805,15 +819,17 @@ const char *t_Device::StateStr (void) const
    const char *pStr;
    switch (State)
    {
-      case Idle         : pStr = "Idle";            break;
-      case Queued       : pStr = "Queued";          break;
-      case Acquire      : pStr = "Acquire";         break;
-      case AcquirePaused: pStr = "AcquirePaused";   break;
-      case Verify       : pStr = "Verify";          break;
-      case VerifyPaused : pStr = "VerifyPaused";    break;
-      case Cleanup      : pStr = "Cleanup";         break;
-      case Finished     : pStr = "Finished";        break;
-      case Aborted      : pStr = "Aborted";         break;
+      case Idle         : pStr = "Idle";           break;
+      case Queued       : pStr = "Queued";         break;
+      case Launch       : pStr = "Launch";         break;
+      case LaunchPaused : pStr = "LaunchPaused";   break;
+      case Acquire      : pStr = "Acquire";        break;
+      case AcquirePaused: pStr = "AcquirePaused";  break;
+      case Verify       : pStr = "Verify";         break;
+      case VerifyPaused : pStr = "VerifyPaused";   break;
+      case Cleanup      : pStr = "Cleanup";        break;
+      case Finished     : pStr = "Finished";       break;
+      case Aborted      : pStr = "Aborted";        break;
       default           : pStr = "Unknown";
    }
 
@@ -846,7 +862,7 @@ void t_Device::ProcessTokenString (QString &Str, t_pDevice pDevice)
 
    if (pDevice)
    {
-      CHK_EXIT (t_File::GetFormatExtension (pDevice, NULL, &Extension))
+      CHK_EXIT (t_File::GetFormatExtension (pDevice, nullptr, &Extension))
 
       DeviceReplace (Str, "%dev%"            , pDevice->LinuxDevice );
       DeviceReplace (Str, "%Size%"           , pDevice->Size        );
@@ -1013,7 +1029,7 @@ APIRET t_DeviceList::MatchDevice (t_pcDevice pDevCmp, t_pDevice &pDevMatch)
    }
 
    if (!Found)
-      pDevMatch = NULL;
+      pDevMatch = nullptr;
 
    return NO_ERROR;
 }
@@ -1041,3 +1057,29 @@ bool t_DeviceList::UsedAsCloneDestination (t_pcDevice pDevChk)
    }
    return false;
 }
+
+QString t_DeviceList::GetOverallAcquisitionSpeed (void)
+{
+   QString Result;
+   double  Sum   = 0.0;
+   int     Count = 0;
+
+   t_pcDevice pDevice;
+   int         i;
+
+   for (i=0; i<count(); i++)
+   {
+      pDevice = at(i);
+      if ((pDevice->GetState() == t_Device::Acquire) ||
+          (pDevice->GetState() == t_Device::Launch)  ||
+          (pDevice->GetState() == t_Device::Verify))
+      {
+         Count++;
+         Sum  += pDevice->PrevSpeed;
+      }
+      if (Count)
+           Result = MainGetpNumberLocale()->toString (Sum, 'f', 2);
+      else Result = QString::null;
+   }
+   return Result;
+}
