@@ -9,7 +9,8 @@
 //  Module:         Dialog that is opened when aborting an acquisition
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -58,7 +59,7 @@ t_DlgAbort::t_DlgAbort (t_pcDevice pDevice, QWidget *pParent, Qt::WindowFlags Fl
 {
    static bool Initialised = false;
    QString     Text;
-   bool        Acquisition;
+   bool        Acquisition, Tick;
 
    if (!Initialised)
    {
@@ -69,9 +70,11 @@ t_DlgAbort::t_DlgAbort (t_pcDevice pDevice, QWidget *pParent, Qt::WindowFlags Fl
    QTUTIL_SET_FONT (this, FONTOBJECT_MESSAGE_DIALOGS)
 
    pOwn = new t_DlgAbortLocal;
-   pOwn->pCheckBoxDelete = NULL;
+   pOwn->pCheckBoxDelete = nullptr;
 
    Acquisition = ((pDevice->GetState() == t_Device::Acquire)       ||
+                  (pDevice->GetState() == t_Device::Launch)        ||
+                  (pDevice->GetState() == t_Device::LaunchPaused)  ||
                   (pDevice->GetState() == t_Device::AcquirePaused) ||
                   (pDevice->GetState() == t_Device::Queued));
    if (Acquisition)
@@ -84,9 +87,17 @@ t_DlgAbort::t_DlgAbort (t_pcDevice pDevice, QWidget *pParent, Qt::WindowFlags Fl
    QPushButton *pButtonOk    = new QPushButton (QObject::tr("Ok"    ), this);
    QPushButton *pButtonCancel= new QPushButton (QObject::tr("Cancel"), this);
    if (!pDevice->Acquisition1.Clone)
-   {
-      pOwn->pCheckBoxDelete = new QCheckBox (tr("Delete partial image files"), this);
-      pOwn->pCheckBoxDelete->setChecked (Acquisition);
+   {      
+      Tick = false;
+      switch (CONFIG(DeleteAbortedImageFiles))
+      {
+         case CFG_BOOLEANAUTO_TRUE:  Tick = true;        break;
+         case CFG_BOOLEANAUTO_FALSE: Tick = false;       break;
+         case CFG_BOOLEANAUTO_AUTO:  Tick = Acquisition; break;
+         default: CHK_EXIT (ERROR_DLGABORT_INVALID_CONFIG_SETTING)
+      }
+      pOwn->pCheckBoxDelete = new QCheckBox (tr("Delete image files already created"), this);
+      pOwn->pCheckBoxDelete->setChecked (Tick);
    }
 
    pMainLayout->addWidget   (pLabel);
