@@ -9,7 +9,8 @@
 //  Module:         Acquisition dialog
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -53,8 +54,8 @@
 //           Constants
 // -----------------------------
 
-const char *DLGACQUIRE_DEFAULT_EMPTY_FILENAME   = "Out";  // Default image file name if - after removing special chars - the file name is empty.
-const char *DLGACQUIRE_PROPERTY_SENDER_LINEEDIT = "SenderLineEdit";
+static const char *DLGACQUIRE_DEFAULT_EMPTY_FILENAME   = "Out";  // Default image file name if - after removing special chars - the file name is empty.
+static const char *DLGACQUIRE_PROPERTY_SENDER_LINEEDIT = "SenderLineEdit";
 
 // -----------------------------
 //           Classes
@@ -155,7 +156,7 @@ static t_pCfgDlgAcquireField DlgAcquireGetField (const QString &Name)
          return pDlgAcquireField;
    }
    LOG_ERROR ("DlgAcquire field %s not found", QSTR_TO_PSZ(Name))
-   return NULL;
+   return nullptr;
 }
 
 
@@ -261,12 +262,12 @@ t_CfgEntryMode t_DlgAcquire::EntryMode (t_pCfgDlgAcquireField pField)
 
 APIRET t_DlgAcquire::AddField (t_pDevice pDevice, t_pCfgDlgAcquireField pField, QGridLayout *pLayout, int *pRow, int *pCol, bool ForceLastEnteredValues)
 {
-   t_pDlgAcquireLineEdit  pLineEdit     = NULL;
-   QCheckBox             *pCheckBox     = NULL;
-   QComboBox             *pComboBox     = NULL;
-   QLabel                *pLabel        = NULL;
-   QWidget               *pEntryWidget  = NULL;
-   QToolButton           *pButtonBrowse = NULL;
+   t_pDlgAcquireLineEdit  pLineEdit     = nullptr;
+   QCheckBox             *pCheckBox     = nullptr;
+   QComboBox             *pComboBox     = nullptr;
+   QLabel                *pLabel        = nullptr;
+   QWidget               *pEntryWidget  = nullptr;
+   QToolButton           *pButtonBrowse = nullptr;
    QString                 Set;
    bool                    Ok;
 
@@ -404,13 +405,13 @@ static APIRET DlgAcquireGetCol (int i, t_pcCfgColumn *ppColCfg, t_pMainWindowCol
    if ((*ppColCfg)->ShowInCloneTable)
    {
       *ppColDef = MainWindowGetColumn ((*ppColCfg)->Name);
-      if (*ppColDef == NULL)
+      if (*ppColDef == nullptr)
          CHK(ERROR_DLGACQUIRE_UNKNOWN_COLUMN)
    }
    else
    {
-      *ppColCfg = NULL;
-      *ppColDef = NULL;
+      *ppColCfg = nullptr;
+      *ppColDef = nullptr;
    }
 
    return NO_ERROR;
@@ -464,11 +465,11 @@ APIRET t_DlgAcquire::InsertDeviceTableRow (QTableWidget *pTable, int Row, t_pDev
    else if (pDeviceList->UsedAsCloneDestination(pDevDst)) Remark = tr("Used in another clone operation");
    else                                                 { Remark = tr("Ok for cloning"); Selectable = true;}
 
-   #define ADD_ITEM(Str)                                                                             \
-   {                                                                                                 \
-      pItem = new t_DlgAcquireTableWidgetItem (pDevDst, Str);                                        \
-      pTable->setItem (Row, Col++, pItem);                                                           \
-      pItem->setFlags (Selectable ? (Qt::ItemIsSelectable | Qt::ItemIsEnabled) : Qt::ItemFlags(0));  \
+   #define ADD_ITEM(Str)                                                                            \
+   {                                                                                                \
+      pItem = new t_DlgAcquireTableWidgetItem (pDevDst, Str);                                       \
+      pTable->setItem (Row, Col++, pItem);                                                          \
+      pItem->setFlags (Selectable ? (Qt::ItemIsSelectable | Qt::ItemIsEnabled) : Qt::NoItemFlags);  \
    }
 
    for (i=0, Col=0; i<Cols; i++)
@@ -626,7 +627,7 @@ t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDevice
    pOwn    = new t_DlgAcquireLocal;
    pOwn->pDevice       = pDevice;
    pOwn->Clone         = Clone;
-   pOwn->pDeviceTable  = NULL;
+   pOwn->pDeviceTable  = nullptr;
    pOwn->Duplicate     = Duplicate;
    pOwn->pAcquisition1 = pAcquisition1;
    pOwn->pDeviceList   = pDeviceList;
@@ -677,10 +678,10 @@ t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDevice
       CHK_EXIT (t_File::GetFormatDescription (t_File::DD  , false, 0, Str))            ButtonTextDD  = "&" + Str;
       CHK_EXIT (t_File::GetFormatDescription (t_File::EWF , false, 0, Str))            ButtonTextEWF = "&" + Str;
       CHK_EXIT (t_File::GetFormatDescription (t_File::AAFF, false, 0, Str))            ButtonTextAFF = "&" + Str;
-      CHK_EXIT (t_File::GetFormatExtension   (t_File::DD  , false, 0, NULL, &Str))
-      CHK_EXIT (t_File::GetFormatExtension   (t_File::DD  , false, 3, NULL, &StrAlt))  ButtonTextDD += " " + tr("(file extension %1 or %2)") .arg (Str) .arg (StrAlt);
-      CHK_EXIT (t_File::GetFormatExtension   (t_File::EWF , false, 0, NULL, &Str))     ButtonTextEWF+= " " + tr("(file extension %1)") .arg (Str);
-      CHK_EXIT (t_File::GetFormatExtension   (t_File::AAFF, false, 0, NULL, &Str))     ButtonTextAFF+= " " + tr("(file extension %1)") .arg (Str);
+      CHK_EXIT (t_File::GetFormatExtension   (t_File::DD  , false, 0, nullptr, &Str))
+      CHK_EXIT (t_File::GetFormatExtension   (t_File::DD  , false, 3, nullptr, &StrAlt))  ButtonTextDD += " " + tr("(file extension %1 or %2)") .arg (Str) .arg (StrAlt);
+      CHK_EXIT (t_File::GetFormatExtension   (t_File::EWF , false, 0, nullptr, &Str))     ButtonTextEWF+= " " + tr("(file extension %1)") .arg (Str);
+      CHK_EXIT (t_File::GetFormatExtension   (t_File::AAFF, false, 0, nullptr, &Str))     ButtonTextAFF+= " " + tr("(file extension %1)") .arg (Str);
 
       pOwn->pRadioButtonFormatDD  = new QRadioButton (ButtonTextDD , this);
       pOwn->pRadioButtonFormatEWF = new QRadioButton (ButtonTextEWF, this);
@@ -810,8 +811,8 @@ t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDevice
    }
 
    ADD_BUTTON (pOwn->pButtonOk, QObject::tr("Ok"))
-   pOwn->pButtonDuplicate = NULL;
-   pOwn->pButtonBack      = NULL;
+   pOwn->pButtonDuplicate = nullptr;
+   pOwn->pButtonBack      = nullptr;
    if (Duplicate)
       ADD_BUTTON (pOwn->pButtonBack, tr("Back..."))
    else if (CONFIG(DuplicateImage))
@@ -827,8 +828,8 @@ t_DlgAcquire::t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDevice
       pLayoutButtons->addWidget (pButton, 2);   \
    }
 
-   pOwn->pButtonDuplicate = NULL;
-   pOwn->pButtonBack      = NULL;
+   pOwn->pButtonDuplicate = nullptr;
+   pOwn->pButtonBack      = nullptr;
    ADD_BUTTON (pOwn->pButtonCancel, QObject::tr("Cancel"))
    pLayoutButtons->addStretch(1);
    if (CONFIG(DuplicateImage))
@@ -1215,7 +1216,7 @@ APIRET t_DlgAcquire::CheckWriteAccess (t_pcDevice pDevice, const QString &Path,
 
    LOG_INFO ("[%s] Trying write access to test file %s", QSTR_TO_PSZ(pDevice->LinuxDevice), QSTR_TO_PSZ(TestFileName))
    pFile = fopen (QSTR_TO_PSZ(TestFileName), "w");
-   Ok = (pFile != NULL);
+   Ok = (pFile != nullptr);
    if (!Ok)
    {
       LOG_INFO ("[%s] Opening test file %s failed", QSTR_TO_PSZ(pDevice->LinuxDevice), QSTR_TO_PSZ(TestFileName))
@@ -1271,7 +1272,7 @@ void t_DlgAcquire::SlotCancel    (void) { done (t_DlgAcquire::ButtonCancel); }
 
 void t_DlgAcquire::Accept (bool DuplicatePressed)
 {
-   t_Acquisition                Acquisition (NULL);
+   t_Acquisition                Acquisition (nullptr);
    t_pDevice                   pDevice;
    t_pDlgAcquireLineEdit       pLineEditImageDirectory         , pLineEditImageFilename         , pLineEditInfoDirectory         , pLineEditInfoFilename;
    QString                              ImageDirectoryCorrected,          ImageFilenameCorrected,          InfoDirectoryCorrected,          InfoFilenameCorrected;
