@@ -9,7 +9,8 @@
 //  Module:         Acquisition dialog
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -27,10 +28,10 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#ifndef __DLGACQUIRE_H__
-#define __DLGACQUIRE_H__
+#ifndef DLGACQUIRE_H
+#define DLGACQUIRE_H
 
-#ifndef __COMMON_H__
+#ifndef COMMON_H
    #include "common.h"
 #endif
 
@@ -40,11 +41,11 @@
    #include <QtGui>     //lint !e537 Repeated include
 #endif
 
-#ifndef __DEVICE_H__
+#ifndef DEVICE_H
   #include "device.h"
 #endif
 
-#ifndef __CONFIG_H__
+#ifndef CONFIG_H
    class   t_CfgEntryMode;
    class   t_CfgDlgAcquireField;
    typedef t_CfgDlgAcquireField *t_pCfgDlgAcquireField;
@@ -65,7 +66,7 @@ class t_DlgAcquire: public QDialog
 
    public:
       t_DlgAcquire ();
-      t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDeviceList, bool Duplicate = false, QWidget *pParent=NULL, Qt::WindowFlags Flags=0, bool ForceLastEnteredValues=false, t_pAcquisition pAcquisition1=NULL);
+      t_DlgAcquire (t_pDevice pDevice, bool Clone, t_pDeviceList pDeviceList, bool Duplicate = false, QWidget *pParent=nullptr, Qt::WindowFlags Flags=0, bool ForceLastEnteredValues=false, t_pAcquisition pAcquisition1=nullptr);
      ~t_DlgAcquire ();
 
       APIRET GetParameters (t_Acquisition &Acquisition, bool RememberLastUsedValues=true);
