@@ -9,7 +9,8 @@
 //  Module:         Wait dialog
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -27,10 +28,10 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#ifndef __DLGWAIT_H__
-#define __DLGWAIT_H__
+#ifndef DLGWAIT_H
+#define DLGWAIT_H
 
-#ifndef __COMMON_H__
+#ifndef COMMON_H
    #include "common.h"
 #endif
 
@@ -48,7 +49,7 @@ class t_DlgWait: public QDialog
 
    public:
       t_DlgWait ();
-      t_DlgWait (const QString &Title, const QString &Message, QWidget *pParent=NULL, Qt::WindowFlags Flags=0);
+      t_DlgWait (const QString &Title, const QString &Message, QWidget *pParent=nullptr, Qt::WindowFlags Flags=0);
      ~t_DlgWait ();
 
       static APIRET Show (const QString &Title, const QString &Message);
