@@ -9,7 +9,8 @@
 //  Module:         The central queues for pipelined data processing
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -27,12 +28,12 @@
 // You should have received a copy of the GNU General Public License
 // along with Guymager. If not, see <http://www.gnu.org/licenses/>.
 
-#ifndef __FIFO_H__
-#define __FIFO_H__
+#ifndef FIFO_H
+#define FIFO_H
 
 #include <QQueue>
 
-#ifndef __COMMON_H__
+#ifndef COMMON_H
    #include "common.h"
 #endif
 
@@ -77,8 +78,9 @@ typedef struct
    t_AewfPreprocess    AewfPreprocess;
 
    qulonglong          Nr;                    // Set to FIFO_NR_NOTSET if nr is not known yet
-   unsigned char       Buffer[];              //lint !e1501  Has zero size
-   int                 MagicEnd;              // Do not reference MagicEnd in this structure, use the macros below instead!
+   unsigned char       Buffer[0];             //lint !e1501  Has zero size
+   int                 MagicEnd;              // Do not reference MagicEnd in this structure, use the macros below instead! MagicEnd 
+                                              // nevertheless must not be commented out as sizeof calculation would otherwise become wrong
 } t_FifoBlock, *t_pFifoBlock;
 
 #define FIFO_SET_MAGIC_END(pFifoBlock)  *((int *)&(pFifoBlock->Buffer[pFifoBlock->BufferSize])) = FIFO_MAGIC_END;
@@ -201,7 +203,7 @@ class t_FifoCompressOut: public t_Fifo
 //             Error codes
 // ------------------------------------
 
-   #ifdef __MODULES_H__
+   #ifdef MODULES_H
       enum
       {
          ERROR_FIFO_MALLOC_FAILED = ERROR_BASE_FIFO + 1,
