@@ -4,7 +4,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="+581"/>
+        <location filename="main.cpp" line="+589"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Keine Root-Rechte</translation>
@@ -17,14 +17,14 @@ Continue anyway?</source>
 Trotzdem fortfahren?</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1491"/>
+        <location filename="threadwrite.cpp" line="+1504"/>
         <source>Deleting %1</source>
         <translation>Lösche %1</translation>
     </message>
     <message>
-        <location filename="dlgabort.cpp" line="+84"/>
-        <location filename="dlgacquire.cpp" line="+812"/>
-        <location filename="dlgdirsel.cpp" line="+107"/>
+        <location filename="dlgabort.cpp" line="+87"/>
+        <location filename="dlgacquire.cpp" line="+813"/>
+        <location filename="dlgdirsel.cpp" line="+108"/>
         <source>Ok</source>
         <translation>Ok</translation>
     </message>
@@ -37,7 +37,7 @@ Trotzdem fortfahren?</translation>
         <translation>Abbruch</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="+68"/>
+        <location filename="file.cpp" line="+69"/>
         <source>Linux dd raw image</source>
         <translation>Linux dd-Image</translation>
     </message>
@@ -52,7 +52,7 @@ Trotzdem fortfahren?</translation>
         <translation>AFF-Format</translation>
     </message>
     <message>
-        <location filename="threadscan.cpp" line="+1441"/>
+        <location filename="threadscan.cpp" line="+1442"/>
         <source>Guymager cannot scan the devices connected to this computer.</source>
         <translation>Guymager kann die angeschlossenen Geräte nicht abfragen.</translation>
     </message>
@@ -167,7 +167,7 @@ Belegung
 [%]</translation>
     </message>
     <message>
-        <location filename="mainwindow.h" line="+48"/>
+        <location filename="mainwindow.h" line="+49"/>
         <source>SerialNr</source>
         <translation>Serien-
 nummer</translation>
@@ -297,17 +297,21 @@ Geschwindigkeit
         <translation>Möchten Sie die Akquisition von %1 abbrechen?</translation>
     </message>
     <message>
-        <location line="+10"/>
         <source>Delete partial image files</source>
-        <translation>Partielle Image-Dateien löschen</translation>
+        <translation type="vanished">Partielle Image-Dateien löschen</translation>
     </message>
     <message>
-        <location line="-9"/>
+        <location line="+1"/>
         <source>Do you want to abort the verification of %1?</source>
         <translation>Möchten Sie die Verifizierung von %1 abbrechen?</translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="+17"/>
+        <source>Delete image files already created</source>
+        <translation>Bereits erzeugte Image-Dateien löschen</translation>
+    </message>
+    <message>
+        <location line="+12"/>
         <source>Abort?</source>
         <comment>Dialog title</comment>
         <translation>Abbrechen?</translation>
@@ -316,8 +320,8 @@ Geschwindigkeit
 <context>
     <name>t_DlgAcquire</name>
     <message>
-        <location filename="config.h" line="+278"/>
-        <location filename="table.cpp" line="+351"/>
+        <location filename="config.h" line="+287"/>
+        <location filename="table.cpp" line="+352"/>
         <source>EwfCaseNumber</source>
         <translation>Fallnummer</translation>
     </message>
@@ -793,7 +797,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_Info</name>
     <message>
-        <location filename="info.cpp" line="+202"/>
+        <location filename="info.cpp" line="+203"/>
         <source>Command executed: %1</source>
         <translation>Ausgeführter Befehl: %1</translation>
     </message>
@@ -815,7 +819,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_InfoField</name>
     <message>
-        <location filename="infofield.cpp" line="+110"/>
+        <location filename="infofield.cpp" line="+113"/>
         <source>Size</source>
         <translation>Größe</translation>
     </message>
@@ -840,12 +844,17 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation>Aktuelle Geschwindigkeit</translation>
     </message>
     <message>
-        <location line="+17"/>
+        <location line="+5"/>
+        <source>Overall speed (all acquisitions)</source>
+        <translation>Gesamtgeschw. (über alle Akquisitionen)</translation>
+    </message>
+    <message>
+        <location line="+13"/>
         <source>bytes</source>
         <translation>Bytes</translation>
     </message>
     <message>
-        <location line="-15"/>
+        <location line="-16"/>
         <source>Hash calculation</source>
         <translation>Hash-Berechnung</translation>
     </message>
@@ -885,7 +894,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation>Verifikation Image</translation>
     </message>
     <message>
-        <location line="+88"/>
+        <location line="+91"/>
         <location line="+9"/>
         <location line="+6"/>
         <source>on</source>
@@ -901,7 +910,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation>aus</translation>
     </message>
     <message>
-        <location line="-114"/>
+        <location line="-117"/>
         <source>Additional state info</source>
         <translation>Status-Zusatzinformation</translation>
     </message>
@@ -931,7 +940,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
 <context>
     <name>t_MainWindow</name>
     <message>
-        <location filename="device.cpp" line="+399"/>
+        <location filename="device.cpp" line="+401"/>
         <source>Local device</source>
         <translation>Lokales Gerät</translation>
     </message>
@@ -941,7 +950,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation>--</translation>
     </message>
     <message>
-        <location line="+60"/>
+        <location line="+66"/>
         <source>Cleanup</source>
         <translation>Aufräumen</translation>
     </message>
@@ -955,7 +964,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation type="obsolete">Abbruch - Fehler &quot;Reason none&quot;</translation>
     </message>
     <message>
-        <location line="-355"/>
+        <location line="-362"/>
         <source>Aborted by user</source>
         <translation>Abbruch durch Benutzer</translation>
     </message>
@@ -968,7 +977,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation type="obsolete">Abbruch - Lesefehler</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="+292"/>
+        <location filename="mainwindow.cpp" line="+293"/>
         <source>&amp;Rescan</source>
         <translation>&amp;Auffrischen</translation>
     </message>
@@ -984,7 +993,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation>Gerät bereits vorhanden</translation>
     </message>
     <message>
-        <location line="+160"/>
+        <location line="+190"/>
         <source>There are active acquisitions. Do you really want to abort them and quit?</source>
         <translation>GUYMAGER hat noch Akquisitionen laufen. Möchten Sie diese abbrechen und das Programm verlassen?</translation>
     </message>
@@ -1029,7 +1038,7 @@ Benutzt libguytools %5</translation>
         <translation>GUYMAGER verlassen</translation>
     </message>
     <message>
-        <location line="-355"/>
+        <location line="-385"/>
         <source>&amp;Devices</source>
         <translation>&amp;Geräte</translation>
     </message>
@@ -1064,7 +1073,23 @@ Benutzt libguytools %5</translation>
         <translation>Über &amp;Qt</translation>
     </message>
     <message>
-        <location line="+413"/>
+        <location line="+443"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Version timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Linked with libewf %5 %6</source>
+        <translation>GUYMAGER ist ein Linux-basierter, forensischer Imager
+
+Version: %1
+Versionszeitstempel: %2
+Kompiliert mit gcc %3
+Benutzt libguytools %4
+Benutzt libewf %5 %6</translation>
+    </message>
+    <message>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
 Version: %1
@@ -1072,7 +1097,7 @@ Compilation timestamp: %2
 Compiled with gcc %3
 Linked with libguytools %4
 Linked with libewf %5 %6</source>
-        <translation>GUYMAGER ist ein Linux-basierter, forensischer Imager
+        <translation type="vanished">GUYMAGER ist ein Linux-basierter, forensischer Imager
 
 Version: %1
 Zeitstempel der Kompilation: %2
@@ -1085,14 +1110,21 @@ Benutzt libewf %5 %6</translation>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
 Version: %1
-Compilation timestamp: %2
+Version timestamp: %2
 Compiled with gcc %3
 Linked with libguytools %4
 Compiled without libewf support</source>
+        <oldsource>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Compiled without libewf support</oldsource>
         <translation>GUYMAGER ist ein Linux-basierter, forensischer Imager
 
 Version: %1
-Zeitstempel der Kompilation: %2
+Versionszeitstempel: %2
 Kompiliert mit gcc %3
 Benutzt libguytools %4
 Ohne libewf-Unterstützung kompiliert.</translation>
@@ -1106,7 +1138,7 @@ Ohne libewf-Unterstützung kompiliert.</translation>
         <translation type="obsolete">Verifikation läuft</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="+352"/>
+        <location filename="device.cpp" line="+359"/>
         <source>Device disconnected, acquisition paused</source>
         <translation>Gerät abgeschaltet, Akquisition unterbrochen</translation>
     </message>
@@ -1146,7 +1178,7 @@ Ohne libewf-Unterstützung kompiliert.</translation>
         <translation>Ja</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-446"/>
+        <location filename="mainwindow.cpp" line="-476"/>
         <source>Rescan devices and update table</source>
         <translation>Geräte neu einlesen und Tabelle auffrischen</translation>
     </message>
@@ -1194,17 +1226,17 @@ Ohne libewf-Unterstützung kompiliert.</translation>
         <translation>Das Gerät bzw. die Datei kann nicht ausgewählt werden da seine Grösse 0 Byte beträgt.</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-168"/>
+        <location filename="device.cpp" line="-174"/>
         <source>Used in clone operation</source>
         <translation>Belegt durch Klon-Operation</translation>
     </message>
     <message>
-        <location line="+15"/>
+        <location line="+17"/>
         <source>Aborting...</source>
         <translation>Abbruch angefragt...</translation>
     </message>
     <message>
-        <location line="+163"/>
+        <location line="+167"/>
         <source>none</source>
         <comment>column hidden areas</comment>
         <translation>keine</translation>
@@ -1229,7 +1261,7 @@ Ohne libewf-Unterstützung kompiliert.</translation>
         <translation type="obsolete">Abbruch - Startfehler Akquisition</translation>
     </message>
     <message>
-        <location line="+416"/>
+        <location line="+446"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation>(inaktiv, da das Guymager-interne EWF-Modul konfiguriert ist)</translation>
     </message>
@@ -1250,10 +1282,15 @@ Benutzt libewf %4 %5
 Benutzt libguytools %6</translation>
     </message>
     <message>
-        <location filename="device.cpp" line="-468"/>
+        <location filename="device.cpp" line="-475"/>
         <source>Acquisition start failure</source>
         <translation>Startfehler Akquisition</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Device (re)moved</source>
+        <translation>Gerät entfernt oder geändert</translation>
+    </message>
     <message>
         <location line="+1"/>
         <source>Device read error</source>
@@ -1305,7 +1342,17 @@ Benutzt libguytools %6</translation>
         <translation>Image 2 Schreibfehler Info-Datei</translation>
     </message>
     <message>
-        <location line="+278"/>
+        <location line="+281"/>
+        <source>Launched, device disconnected</source>
+        <translation>Akquisition unterbrochen beim Start</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Launched</source>
+        <translation>Akquisition gestartet</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>Running</source>
         <translation>Akquisition läuft</translation>
     </message>
@@ -1315,7 +1362,7 @@ Benutzt libguytools %6</translation>
         <translation>Verifizierung läuft</translation>
     </message>
     <message>
-        <location line="+53"/>
+        <location line="+54"/>
         <location line="+26"/>
         <source>Verified &amp; ok</source>
         <comment>Status column</comment>
@@ -1378,7 +1425,7 @@ Benutzt libguytools %6</translation>
         <translation>Verifikation schlug fehl</translation>
     </message>
     <message>
-        <location line="-395"/>
+        <location line="-401"/>
         <source>Too many bad sectors</source>
         <translation>Zu viele schlechte Sektoren</translation>
     </message>
@@ -1425,7 +1472,13 @@ Benutzt libguytools %6</translation>
         <translation>Guymager</translation>
     </message>
     <message>
-        <location line="+8"/>
+        <location line="+3"/>
+        <source>Version timestamp:: %1</source>
+        <comment>Info file</comment>
+        <translation>Zeitstempel der Version:: %1</translation>
+    </message>
+    <message>
+        <location line="+5"/>
         <source>(not used as Guymager is configured to use its own EWF module)</source>
         <comment>Info file</comment>
         <translation>(inaktiv, da das Guymager-interne EWF-Modul konfiguriert ist)</translation>
@@ -1468,7 +1521,7 @@ Benutzt libguytools %6</translation>
         <translation>Geräte-Informationen</translation>
     </message>
     <message>
-        <location line="+579"/>
+        <location line="+581"/>
         <source>Finished successfully</source>
         <comment>Info file</comment>
         <translation>Erfolgreich beendet</translation>
@@ -1549,7 +1602,7 @@ Benutzt libguytools %6</translation>
         <translation>Akquisition vor Beginn der MD5-Verifizierung abgebrochen</translation>
     </message>
     <message>
-        <location line="-642"/>
+        <location line="-644"/>
         <source>Linux device:: %1</source>
         <comment>Info file</comment>
         <translation>Linux-Gerät:: %1</translation>
@@ -1561,7 +1614,7 @@ Benutzt libguytools %6</translation>
         <translation>Grösse:: %1 (%2)</translation>
     </message>
     <message>
-        <location line="+643"/>
+        <location line="+645"/>
         <location line="+24"/>
         <source>Acquisition started:: %1</source>
         <comment>Info file</comment>
@@ -1600,19 +1653,18 @@ Benutzt libguytools %6</translation>
         <translation>MD5-Hash:: %1</translation>
     </message>
     <message>
-        <location line="-626"/>
+        <location line="-628"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation>Version:: %1</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Compilation timestamp:: %1</source>
         <comment>Info file</comment>
-        <translation>Zeitstempel der Kompilation:: %1</translation>
+        <translation type="vanished">Zeitstempel der Kompilation:: %1</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+2"/>
         <source>Compiled with:: %1 %2</source>
         <comment>Info file</comment>
         <translation>Kompiliert mit:: %1 %2</translation>
@@ -1629,7 +1681,7 @@ Benutzt libguytools %6</translation>
         <translation>Version libguytools:: %1</translation>
     </message>
     <message>
-        <location line="+683"/>
+        <location line="+685"/>
         <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
         <comment>Info file</comment>
         <translation>Geschwindigkeit MD5-Verifizierung:: %1 MByte/s (%2 Stunden, %3 Minuten und %4 Sekunden)</translation>
@@ -1640,7 +1692,7 @@ Benutzt libguytools %6</translation>
         <translation type="obsolete">Hash-Berechnung:: aus</translation>
     </message>
     <message>
-        <location line="-639"/>
+        <location line="-641"/>
         <source>Source verification:: on</source>
         <comment>Info file</comment>
         <translation>Verifikation Quellmedium:: ein</translation>
@@ -1652,7 +1704,7 @@ Benutzt libguytools %6</translation>
         <translation>Verifikation Quellmedium:: aus</translation>
     </message>
     <message>
-        <location line="+507"/>
+        <location line="+509"/>
         <source>(during source verification)</source>
         <comment>Info file</comment>
         <translation>(während der Verifikation des Quellmediums)</translation>
@@ -1679,7 +1731,7 @@ Benutzt libguytools %6</translation>
         <translation type="obsolete">Hash-Berechnung:: SHA-256</translation>
     </message>
     <message>
-        <location line="-584"/>
+        <location line="-586"/>
         <source>Image path and file name:: %1</source>
         <comment>Info file</comment>
         <translation>Image-Pfad und Datei:: %1</translation>
@@ -1703,7 +1755,7 @@ Benutzt libguytools %6</translation>
         <translation>Verifikation Image-Datei:: aus</translation>
     </message>
     <message>
-        <location line="+516"/>
+        <location line="+518"/>
         <source>Aborted, too many bad sectors (&gt; %1)</source>
         <comment>Info file</comment>
         <translation>Abbruch, zu viele schlechte Sektoren</translation>
@@ -1771,7 +1823,7 @@ Benutzt libguytools %6</translation>
         <translation>Versuchen Sie eine erneute Akquisition.</translation>
     </message>
     <message>
-        <location line="-844"/>
+        <location line="-846"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation>Sondergerät entfernen</translation>
@@ -1824,7 +1876,7 @@ Benutzt libguytools %6</translation>
         <translation>Gerät durch Klon-Operation belegt - kann nicht akquiriert werden</translation>
     </message>
     <message>
-        <location line="+866"/>
+        <location line="+868"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation>Erzeugte Image-Dateien und ihre MD5-Hashwerte</translation>
@@ -1844,12 +1896,12 @@ Benutzt libguytools %6</translation>
         <translation>Keine MD5-Hashes verfügbar (der Konfigurationsparameter CalcImageFileMD5 ist abgeschaltet)</translation>
     </message>
     <message>
-        <location line="-881"/>
+        <location line="-883"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation>Kann nicht akquiriert werden - siehe Status-Zusatzinformation</translation>
     </message>
     <message>
-        <location line="+739"/>
+        <location line="+741"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation>Abbruch wegen Fehler beim Schreiben der Image-Datei</translation>
@@ -1866,13 +1918,13 @@ Benutzt libguytools %6</translation>
         <translation>Keine MD5-Hashes verfügbar (das ausgewählte EWF-Format unterstützt das Hashen der Image-Dateien nicht)</translation>
     </message>
     <message>
-        <location line="-672"/>
+        <location line="-674"/>
         <source>Hash calculation:: %1</source>
         <comment>Info file</comment>
         <translation>Hash-Berechnung:: %1</translation>
     </message>
     <message>
-        <location line="+521"/>
+        <location line="+523"/>
         <source>Aborted because of source read error</source>
         <comment>Info file</comment>
         <translation>Abbruch wegen Quellmedium-Lesefehler</translation>
@@ -1902,13 +1954,13 @@ Benutzt libguytools %6</translation>
         <translation>SHA1-Hash Image verifiziert:: %1</translation>
     </message>
     <message>
-        <location line="-607"/>
+        <location line="-609"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation>Versteckte Bereiche: %1</translation>
     </message>
     <message>
-        <location line="+725"/>
+        <location line="+727"/>
         <source>Acquisition/verification aborted - file list may be incomplete</source>
         <translation>Akquisition / Verifikation abgebrochen - die Dateiliste ist möglicherweise unvollständig </translation>
     </message>
