@@ -9,7 +9,8 @@
 //  Module:         Thread for scanning the connected devices
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -172,12 +173,12 @@ class t_ThreadScanWorkerPartedLocal
 {
    public:
       t_ThreadScanWorkerPartedLocal ()
-         :LibPartedLoaded      (false), pLibPartedHandle     (NULL),
-          pFnLibPartedProbeAll (NULL) ,
-          pFnLibPartedGetNext  (NULL) ,
-          pFnLibPartedFreeAll  (NULL)
+         :LibPartedLoaded      (false), pLibPartedHandle (nullptr),
+          pFnLibPartedProbeAll (nullptr) ,
+          pFnLibPartedGetNext  (nullptr) ,
+          pFnLibPartedFreeAll  (nullptr)
       {
-      };
+      }
 
    public:
       bool         LibPartedLoaded;
@@ -293,7 +294,7 @@ t_ThreadScanWorkerParted::t_ThreadScanWorkerParted (t_ThreadScan *pThreadScan, A
    {
       Filename = FilenameList[i];
       pOwn->pLibPartedHandle = dlopen (QSTR_TO_PSZ(Filename), RTLD_NOW);
-      if (pOwn->pLibPartedHandle == NULL)
+      if (pOwn->pLibPartedHandle == nullptr)
       {
          LOG_INFO ("Trying %s -- dlopen returns (%s)", QSTR_TO_PSZ(Filename), dlerror())
          continue;
@@ -309,10 +310,10 @@ t_ThreadScanWorkerParted::t_ThreadScanWorkerParted (t_ThreadScan *pThreadScan, A
          {                                                                                 \
             LOG_INFO ("Trying %s -- dlsym for %s returns (%s)", QSTR_TO_PSZ(Filename), pFnName, dlerror()); \
             dlclose (pOwn->pLibPartedHandle);                                              \
-            pOwn->pLibPartedHandle    = NULL;                                              \
-            pOwn->pFnLibPartedProbeAll= NULL;                                              \
-            pOwn->pFnLibPartedGetNext = NULL;                                              \
-            pOwn->pFnLibPartedFreeAll = NULL;                                              \
+            pOwn->pLibPartedHandle    = nullptr;                                           \
+            pOwn->pFnLibPartedProbeAll= nullptr;                                           \
+            pOwn->pFnLibPartedGetNext = nullptr;                                           \
+            pOwn->pFnLibPartedFreeAll = nullptr;                                           \
             continue;                                                                      \
          }                                                                                 \
          else                                                                              \
@@ -362,7 +363,7 @@ void t_ThreadScanWorkerParted::SlotRescan (void)
    pOwn->pFnLibPartedProbeAll ();
 
    pDeviceList = new t_DeviceList;
-   pPedDev     = NULL;
+   pPedDev     = nullptr;
    while ((pPedDev = pOwn->pFnLibPartedGetNext (pPedDev)))  //lint !e820
    {
       rc = ThreadScanGetSerialNumber (pPedDev->path, SerialNumber);
@@ -428,7 +429,7 @@ typedef struct udev_list_entry * (*t_pFnLibUdev_udev_list_entry_get_next)
 
 #define LibUdevListEntryForEach(list_entry, first_entry) \
    for (list_entry = first_entry;                        \
-        list_entry != NULL;                              \
+        list_entry != nullptr;                              \
         list_entry = pOwn->pFnLibUdev_udev_list_entry_get_next(list_entry))
 
 #pragma GCC diagnostic ignored "-Wunused-result"
@@ -438,26 +439,26 @@ class t_ThreadScanWorkerUdevLocal
    public:
       t_ThreadScanWorkerUdevLocal ()
          :LibUdevLoaded  (false),
-          pLibUdevHandle (NULL)
+          pLibUdevHandle (nullptr)
       {
          ClearFnPointers();
       }
 
       void ClearFnPointers (void)
       {
-         pFnLibUdev_udev_new                           = NULL;
-         pFnLibUdev_udev_unref                         = NULL;
-         pFnLibUdev_udev_device_unref                  = NULL;
-         pFnLibUdev_udev_enumerate_new                 = NULL;
-         pFnLibUdev_udev_enumerate_unref               = NULL;
-         pFnLibUdev_udev_enumerate_add_match_subsystem = NULL;
-         pFnLibUdev_udev_enumerate_add_match_property  = NULL;
-         pFnLibUdev_udev_enumerate_scan_devices        = NULL;
-         pFnLibUdev_udev_enumerate_get_list_entry      = NULL;
-         pFnLibUdev_udev_list_entry_get_name           = NULL;
-         pFnLibUdev_udev_device_new_from_syspath       = NULL;
-         pFnLibUdev_udev_device_get_property_value     = NULL;
-         pFnLibUdev_udev_list_entry_get_next           = NULL;
+         pFnLibUdev_udev_new                           = nullptr;
+         pFnLibUdev_udev_unref                         = nullptr;
+         pFnLibUdev_udev_device_unref                  = nullptr;
+         pFnLibUdev_udev_enumerate_new                 = nullptr;
+         pFnLibUdev_udev_enumerate_unref               = nullptr;
+         pFnLibUdev_udev_enumerate_add_match_subsystem = nullptr;
+         pFnLibUdev_udev_enumerate_add_match_property  = nullptr;
+         pFnLibUdev_udev_enumerate_scan_devices        = nullptr;
+         pFnLibUdev_udev_enumerate_get_list_entry      = nullptr;
+         pFnLibUdev_udev_list_entry_get_name           = nullptr;
+         pFnLibUdev_udev_device_new_from_syspath       = nullptr;
+         pFnLibUdev_udev_device_get_property_value     = nullptr;
+         pFnLibUdev_udev_list_entry_get_next           = nullptr;
       }
 
       // GetFileContents; Join both path parts and read file contents into ppData.
@@ -467,12 +468,12 @@ class t_ThreadScanWorkerUdevLocal
       int GetFileContents (const char *pPath, const char *pSubPath, char **ppData)
       {
          const size_t   MaxSize  = 65536; // If the file is bigger than this then there's surely something wrong
-         char         *pFullPath = NULL;
-         FILE         *pFile     = NULL;
+         char         *pFullPath = nullptr;
+         FILE         *pFile     = nullptr;
          size_t         Read;
          size_t         Size;
 
-         *ppData = NULL;
+         *ppData = nullptr;
 
          // Open file
          // ---------
@@ -592,7 +593,7 @@ t_ThreadScanWorkerUdev::t_ThreadScanWorkerUdev (t_ThreadScan *pThreadScan, APIRE
    {
       Filename = FilenameList[i];
       pOwn->pLibUdevHandle = dlopen (QSTR_TO_PSZ(Filename), RTLD_NOW);
-      if (pOwn->pLibUdevHandle == NULL)
+      if (pOwn->pLibUdevHandle == nullptr)
       {
          LOG_INFO ("Trying %s -- dlopen returns (%s)", QSTR_TO_PSZ(Filename), dlerror())
          continue;
@@ -608,7 +609,7 @@ t_ThreadScanWorkerUdev::t_ThreadScanWorkerUdev (t_ThreadScan *pThreadScan, APIRE
          {                                                                                                  \
             LOG_INFO ("Trying %s -- dlsym for %s returns (%s)", QSTR_TO_PSZ(Filename), pFnName, dlerror()); \
             dlclose (pOwn->pLibUdevHandle);                                                                 \
-            pOwn->pLibUdevHandle = NULL;                                                                    \
+            pOwn->pLibUdevHandle = nullptr;                                                                    \
             pOwn->ClearFnPointers();                                                                        \
             continue;                                                                                       \
          }                                                                                                  \
@@ -669,9 +670,9 @@ void t_ThreadScanWorkerUdev::SlotRescan (void)
    t_pDeviceList  pDeviceList;
    t_pDevice      pDevice;
 
-   struct udev            *pUdev       = NULL;
-   struct udev_enumerate  *pUdevEnum   = NULL;
-   struct udev_device     *pUdevDevice = NULL;
+   struct udev            *pUdev       = nullptr;
+   struct udev_enumerate  *pUdevEnum   = nullptr;
+   struct udev_device     *pUdevDevice = nullptr;
    struct udev_list_entry *pUdevList;
    struct udev_list_entry *pUdevEntry;
    const char             *pPath;
@@ -681,7 +682,7 @@ void t_ThreadScanWorkerUdev::SlotRescan (void)
    const char             *pModel;
    const char             *pRaidUuid;
    const char             *pRaidLevel;
-   char                   *pLoopBacking = NULL;
+   char                   *pLoopBacking = nullptr;
    int                      rc;
    long long int            IsRemovable;
    long long int            IsCD;
@@ -708,7 +709,7 @@ void t_ThreadScanWorkerUdev::SlotRescan (void)
    CHK_UDEV (pOwn->pFnLibUdev_udev_enumerate_scan_devices        (pUdevEnum))
 
    pUdevList = pOwn->pFnLibUdev_udev_enumerate_get_list_entry (pUdevEnum);
-   if (pUdevList == NULL)
+   if (pUdevList == nullptr)
    {
       LOG_ERROR ("No disk block devices found.");
       goto End;
@@ -817,7 +818,7 @@ void t_ThreadScanWorkerUdev::SlotRescan (void)
       if (pLoopBacking)
       {
          free (pLoopBacking);
-         pLoopBacking = NULL;
+         pLoopBacking = nullptr;
       }
    }
 
@@ -847,15 +848,15 @@ class t_ThreadScanWorkerHALLocal
       t_ThreadScanWorkerHALLocal (void)
       {
          pDBusConnection = new QDBusConnection (QDBusConnection::systemBus());
-         pDBusInterface  = NULL;
+         pDBusInterface  = nullptr;
       }
 
      ~t_ThreadScanWorkerHALLocal ()
       {
          QDBusConnection::disconnectFromBus (pDBusConnection->baseService());
          delete pDBusConnection;
-         pDBusConnection = NULL;
-         pDBusInterface  = NULL;
+         pDBusConnection = nullptr;
+         pDBusInterface  = nullptr;
       }
 
    public:
@@ -970,7 +971,7 @@ bool t_ThreadScanWorkerHAL::PropertyContains (const QString &Device, const QStri
 
 void t_ThreadScanWorkerHAL::SlotRescan (void)
 {
-   t_pDeviceList   pDeviceList=NULL;
+   t_pDeviceList   pDeviceList=nullptr;
    t_pDevice       pDevice;
    QDBusMessage     Message;
    QDBusMessage     Reply;
@@ -1125,15 +1126,15 @@ class t_ThreadScanWorkerDevKitLocal
       t_ThreadScanWorkerDevKitLocal (void)
       {
          pDBusConnection = new QDBusConnection (QDBusConnection::systemBus());
-         pDBusInterface  = NULL;
+         pDBusInterface  = nullptr;
       }
 
      ~t_ThreadScanWorkerDevKitLocal ()
       {
          QDBusConnection::disconnectFromBus (pDBusConnection->baseService());
          delete pDBusConnection;
-         pDBusConnection = NULL;
-         pDBusInterface  = NULL;
+         pDBusConnection = nullptr;
+         pDBusInterface  = nullptr;
       }
 
    public:
@@ -1250,7 +1251,7 @@ APIRET t_ThreadScanWorkerDevKit::GetProperty (const QString &Device, const QStri
 
 void t_ThreadScanWorkerDevKit::SlotRescan (void)
 {
-   t_pDeviceList   pDeviceList=NULL;
+   t_pDeviceList   pDeviceList=nullptr;
    t_pDevice       pDevice;
    QDBusMessage    Message;
    QStringList     DeviceList;
@@ -1404,13 +1405,13 @@ static APIRET ThreadScanRegisterErrorCodes (void)
 t_ThreadScan::t_ThreadScan (void)
 {
    CHK_EXIT (ThreadScanRegisterErrorCodes())
-   ppoWorker = NULL;  //lint -esym(613, t_ThreadScan::ppoWorker)  Possible use of NULL pointer
+   ppoWorker = nullptr;  //lint -esym(613, t_ThreadScan::ppoWorker)  Possible use of nullptr
 }
 
 
 static const char *ThreadScanMethodToString (t_CfgScanMethod Method)
 {
-   const char *pStr=NULL;
+   const char *pStr=nullptr;
 
    switch (Method)
    {
@@ -1478,17 +1479,17 @@ APIRET t_ThreadScan::Start (t_ThreadScanWorker **ppWorker)
 
    CHK_EXIT (SetDebugMessage ("Launch thread"))
 
-   #define LAUNCH_WORKER                                                                    \
-   {                                                                                        \
-      *ppWorker   = NULL;                                                                   \
-      ppoWorker   = ppWorker;                                                               \
-        oWorkerRc = NO_ERROR;                                                               \
-      start();                                                                              \
-      /* start(QThread::HighPriority); */                                                   \
-      for ( Wait =  0;                                                                      \
-           (Wait <  THREADSCAN_WAIT_MAX) && (*ppWorker == NULL) && (oWorkerRc==NO_ERROR);   \
-            Wait += THREADSCAN_WAIT_GRANULARITY)                                            \
-         msleep (THREADSCAN_WAIT_GRANULARITY);                                              \
+   #define LAUNCH_WORKER                                                                      \
+   {                                                                                          \
+      *ppWorker   = nullptr;                                                                  \
+      ppoWorker   = ppWorker;                                                                 \
+        oWorkerRc = NO_ERROR;                                                                 \
+      start();                                                                                \
+      /* start(QThread::HighPriority); */                                                     \
+      for ( Wait =  0;                                                                        \
+           (Wait <  THREADSCAN_WAIT_MAX) && (*ppWorker == nullptr) && (oWorkerRc==NO_ERROR);  \
+            Wait += THREADSCAN_WAIT_GRANULARITY)                                              \
+         msleep (THREADSCAN_WAIT_GRANULARITY);                                                \
    }
 
    for (Tries=1;;Tries++)  // Try all scan methods if necessary
@@ -1502,8 +1503,8 @@ APIRET t_ThreadScan::Start (t_ThreadScanWorker **ppWorker)
       {
          if (Tries == SCANMETHOD_COUNT)
          {
-            t_MessageBox::critical (NULL, tr ("Cannot scan devices", "Dialog title"),
-                                          tr ("None of the device scan methods worked. Exiting now."));
+            t_MessageBox::critical (nullptr, tr ("Cannot scan devices", "Dialog title"),
+                                             tr ("None of the device scan methods worked. Exiting now."));
             break;
          }
          CHK (ThreadScanAskUser (Ok))
@@ -1518,7 +1519,7 @@ APIRET t_ThreadScan::Start (t_ThreadScanWorker **ppWorker)
    #undef LAUNCH_WORKER
 
    CHK (oWorkerRc)
-   if (*ppWorker == NULL)
+   if (*ppWorker == nullptr)
       CHK (ERROR_THREADSCAN_NOT_STARTED)
 
    CHK_EXIT (SetDebugMessage ("Thread launched"))
@@ -1539,9 +1540,9 @@ APIRET t_ThreadScan::Stop ()
       QCoreApplication::processEvents (QEventLoop::ExcludeUserInputEvents, THREADSCAN_WAIT_GRANULARITY);
       time (&NowT);
       Wait = (NowT-BeginT)*MSEC_PER_SECOND;
-   } while ((Wait < THREADSCAN_WAIT_MAX) && (*ppoWorker != NULL));
+   } while ((Wait < THREADSCAN_WAIT_MAX) && (*ppoWorker != nullptr));
 
-   if (*ppoWorker != NULL)
+   if (*ppoWorker != nullptr)
       CHK (ERROR_THREADSCAN_NOT_STOPPED)
 
    return NO_ERROR;
@@ -1550,7 +1551,7 @@ APIRET t_ThreadScan::Stop ()
 
 void t_ThreadScan::run (void)
 {
-   t_ThreadScanWorker *pWorker   = NULL;
+   t_ThreadScanWorker *pWorker   = nullptr;
    APIRET               WorkerRc = NO_ERROR;
    QTimer             *pTimer;
    int                    rc;
@@ -1589,7 +1590,7 @@ void t_ThreadScan::run (void)
    CHK_EXIT (SetDebugMessage ("Exit run function"))
    delete pTimer;
    delete *ppoWorker;
-   *ppoWorker = NULL;
+   *ppoWorker = nullptr;
 }
 
 
