@@ -9,7 +9,8 @@
 //  Module:         Thread for writing data.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
+// 2018, 2019, 2020
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -81,14 +82,14 @@ class t_OutputFileDD: public t_OutputFile
           t_OutputFile         (pThreadWrite),
           oFile                (-1),
           oLastCheckT          (0),
-         poVerifyBuff          (NULL),
-         poAcquisition         (NULL),
-         poDevice              (NULL),
+         poVerifyBuff          (nullptr),
+         poAcquisition         (nullptr),
+         poDevice              (nullptr),
           oSplitNr             (0),
           oCurrentVerifyFileNr (0)
       {
-      } //lint -esym(613, t_OutputFileDD::poFile)  Possible use of NULL pointer
-        //lint -esym(668, fclose, fwrite)  Possibly passing NULL pointer
+      } //lint -esym(613, t_OutputFileDD::poFile)  Possible use of nullptr
+        //lint -esym(668, fclose, fwrite)  Possibly passing nullptr
 
       ~t_OutputFileDD (void)
       {
@@ -185,7 +186,7 @@ class t_OutputFileDD: public t_OutputFile
                bool   Error;
 
                pFile = fopen64 (QSTR_TO_PSZ (oFilename), "r");
-               Error = (pFile == NULL);
+               Error = (pFile == nullptr);
                if (!Error)
                   Error = (fclose (pFile) != 0);
                if (Error)
@@ -208,7 +209,7 @@ class t_OutputFileDD: public t_OutputFile
          if (*pPos == 0)       // First call of this function?
          {
             poVerifyBuff = UTIL_MEM_ALLOC (poDevice->FifoBlockSize);
-            if (poVerifyBuff == NULL)
+            if (poVerifyBuff == nullptr)
                CHK (ERROR_THREADWRITE_MALLOC_FAILED);
          }
 
@@ -288,7 +289,7 @@ class t_OutputFileDD: public t_OutputFile
          if (poVerifyBuff && ReleaseMem)
          {
             UTIL_MEM_FREE (poVerifyBuff);
-            poVerifyBuff = NULL;
+            poVerifyBuff = nullptr;
          }
          return NO_ERROR;
       }
@@ -301,7 +302,7 @@ class t_OutputFileDD: public t_OutputFile
       void * GetFileHandle (void)
       {
          if (oFile == -1)
-              return NULL;
+              return nullptr;
          else return &oFile;
       }
 
@@ -364,14 +365,14 @@ class t_OutputFileEWF: public t_OutputFile
       t_OutputFileEWF (t_ThreadWrite *pThreadWrite):
           t_OutputFile (pThreadWrite)
       {
-         poFile                  = NULL;
+         poFile                  = nullptr;
          #if (LIBEWF_VERSION >= 20130416)
-            poLibewfErr          = NULL;
+            poLibewfErr          = nullptr;
          #endif
-         poAcquisition           = NULL,
-         poDevice                = NULL;   //lint -esym(613,t_OutputFileEWF::poDevice)  Prevent lint from telling us about possible null pointers in the following code
-         poVerifyBuff            = NULL;
-         poImageFilenameArr      = NULL;
+         poAcquisition           = nullptr;
+         poDevice                = nullptr;   //lint -esym(613,t_OutputFileEWF::poDevice)  Prevent lint from telling us about possible null pointers in the following code
+         poVerifyBuff            = nullptr;
+         poImageFilenameArr      = nullptr;
           oImageFileCount        = 0;
           oHasCompressionThreads = false;
           oVerification          = false;
@@ -387,7 +388,7 @@ class t_OutputFileEWF: public t_OutputFile
       {
          QString          Uname;
          QString          GuymagerVersion;
-         LIBEWF_HANDLE  *pFile=NULL;
+         LIBEWF_HANDLE  *pFile=nullptr;
          char           *pAsciiFileName;
          QByteArray       AsciiFileName = (pAcquisition->ImagePath + pAcquisition->ImageFilename).toLatin1();
 
@@ -428,12 +429,12 @@ class t_OutputFileEWF: public t_OutputFile
             CHK_EXIT (poThreadWrite->SetDebugMessage ("Verification: Calling libewf_open"))
             #if (LIBEWF_VERSION >= 20130416)
                if (libewf_handle_open(pFile, poImageFilenameArr, oImageFileCount, LIBEWF_ACCESS_FLAG_READ, &poLibewfErr) != 1)
-                  pFile = NULL;
+                  pFile = nullptr;
             # else
                pFile = libewf_open (poImageFilenameArr, oImageFileCount, libewf_get_flags_read());
             #endif
             CHK_EXIT (poThreadWrite->SetDebugMessage ("Verification: Returning from libewf_open"))
-            if (pFile == NULL)
+            if (pFile == nullptr)
             {
                LOG_INFO ("[%s] Error while reopening EWF for verification. The files are:", QSTR_TO_PSZ (poDevice->LinuxDevice))
                for (i=0; i<oImageFileCount; i++)
@@ -447,12 +448,12 @@ class t_OutputFileEWF: public t_OutputFile
 
             #if (LIBEWF_VERSION >= 20130416)
                if (libewf_handle_open(pFile, &pAsciiFileName, 1, LIBEWF_OPEN_WRITE, &poLibewfErr) != 1)
-                  pFile = NULL;
+                  pFile = nullptr;
             #else
                pFile = libewf_open (&pAsciiFileName, 1, LIBEWF_OPEN_WRITE);
             #endif
 
-            if (pFile == NULL)
+            if (pFile == nullptr)
                return ERROR_THREADWRITE_OPEN_FAILED;
 
             CHK (ToolSysInfoUname (Uname))
@@ -537,7 +538,7 @@ class t_OutputFileEWF: public t_OutputFile
                                                                                      checksum_buffer,
                                                                                      pFifoBlock->EwfChunkCRC,
                                                                                      pFifoBlock->EwfWriteCRC,
-                                                                                     NULL);
+                                                                                     nullptr);
             #else
                Written = libewf_raw_write_buffer (poFile, pFifoBlock->Buffer, Size, pFifoBlock->DataSize,
                                                                                     pFifoBlock->EwfCompressionUsed,
@@ -549,7 +550,7 @@ class t_OutputFileEWF: public t_OutputFile
          {
             Size = pFifoBlock->DataSize;
             #if (LIBEWF_VERSION >= 20130416)
-               Written = libewf_handle_write_buffer (poFile, pFifoBlock->Buffer, Size, NULL);
+               Written = libewf_handle_write_buffer (poFile, pFifoBlock->Buffer, Size, nullptr);
             #else
                Written = libewf_write_buffer (poFile, pFifoBlock->Buffer, Size);
             #endif
@@ -574,18 +575,18 @@ class t_OutputFileEWF: public t_OutputFile
          if (*pPos == 0)
          {
             poVerifyBuff = UTIL_MEM_ALLOC (poDevice->FifoBlockSize);
-            if (poVerifyBuff == NULL)
+            if (poVerifyBuff == nullptr)
                CHK (ERROR_THREADWRITE_MALLOC_FAILED);
 
             for (int i=0; i<oImageFileCount; i++)
-               ImageFileHashList.append (new t_ImageFileHash (poImageFilenameArr[i], NULL));  // No MD5 files hashes for EWF files generated by libewf
+               ImageFileHashList.append (new t_ImageFileHash (poImageFilenameArr[i], nullptr));  // No MD5 files hashes for EWF files generated by libewf
          }
          Remaining = poDevice->Size - *pPos;
          ToRead = GETMIN (Remaining, poDevice->FifoBlockSize);
 
          CHK_EXIT (poThreadWrite->SetDebugMessage ("Verification: Calling libewf_read_buffer"))
          #if (LIBEWF_VERSION >= 20130416)
-            Read = libewf_handle_read_buffer (poFile, poVerifyBuff, ToRead, NULL);
+            Read = libewf_handle_read_buffer (poFile, poVerifyBuff, ToRead, nullptr);
          #else
             Read = libewf_read_buffer (poFile, poVerifyBuff, ToRead);
          #endif
@@ -613,7 +614,7 @@ class t_OutputFileEWF: public t_OutputFile
          int              rc;
          int              j;
 
-         if (poFile == NULL)
+         if (poFile == nullptr)
             CHK (ERROR_THREADWRITE_NOT_OPENED)
 
          // Write bad sector list
@@ -638,7 +639,7 @@ class t_OutputFileEWF: public t_OutputFile
                      i++;
                   }
                   #if (LIBEWF_VERSION >= 20130416)
-                     CHK_LIBEWF (libewf_handle_append_acquiry_error (poFile, From, To - From + 1, NULL))
+                     CHK_LIBEWF (libewf_handle_append_acquiry_error (poFile, From, To - From + 1, nullptr))
                   #else
                      CHK_LIBEWF (libewf_add_acquiry_error(poFile, From, To - From + 1))
                   #endif
@@ -653,7 +654,7 @@ class t_OutputFileEWF: public t_OutputFile
             if (poAcquisition->CalcMD5)
             {
                #if (LIBEWF_VERSION >= 20130416)
-                  CHK_LIBEWF (libewf_handle_set_md5_hash (poFile, (uint8_t*)&poDevice->MD5Digest, HASH_MD5_DIGEST_LENGTH, NULL))
+                  CHK_LIBEWF (libewf_handle_set_md5_hash (poFile, (uint8_t*)&poDevice->MD5Digest, HASH_MD5_DIGEST_LENGTH, nullptr))
                #else
                   CHK_LIBEWF (libewf_set_md5_hash (poFile, (uint8_t*)&poDevice->MD5Digest, HASH_MD5_DIGEST_LENGTH))
                #endif
@@ -661,7 +662,7 @@ class t_OutputFileEWF: public t_OutputFile
             if (poAcquisition->CalcSHA1)
             {
                #if (LIBEWF_VERSION >= 20130416)
-                  CHK_LIBEWF (libewf_handle_set_sha1_hash (poFile, (uint8_t*)&poDevice->SHA1Digest, HASH_SHA1_DIGEST_LENGTH, NULL))
+                  CHK_LIBEWF (libewf_handle_set_sha1_hash (poFile, (uint8_t*)&poDevice->SHA1Digest, HASH_SHA1_DIGEST_LENGTH, nullptr))
                #else
                   CHK_LIBEWF (libewf_set_sha1_hash (poFile, (uint8_t*)&poDevice->SHA1Digest, HASH_SHA1_DIGEST_LENGTH))
                #endif
@@ -671,13 +672,13 @@ class t_OutputFileEWF: public t_OutputFile
          // Close and cleanup
          // -----------------
          #if (LIBEWF_VERSION >= 20130416)
-            rc = libewf_handle_close(poFile, NULL);
+            rc = libewf_handle_close(poFile, nullptr);
             if (rc != 0)
             {
                LOG_ERROR ("[%s] Error in libewf function: libewf_handle_close, rc=%d", QSTR_TO_PSZ (poDevice->LinuxDevice), rc)
                return ERROR_THREADWRITE_LIBEWF_FAILED;
             }
-            if (libewf_handle_free(&poFile, NULL) != 1)
+            if (libewf_handle_free(&poFile, nullptr) != 1)
             {
                LOG_ERROR ("[%s] Error in libewf function: libewf_handle_free, rc=%d", QSTR_TO_PSZ (poDevice->LinuxDevice), rc)
                return ERROR_THREADWRITE_LIBEWF_FAILED;
@@ -694,14 +695,14 @@ class t_OutputFileEWF: public t_OutputFile
          if (poVerifyBuff)
          {
             UTIL_MEM_FREE (poVerifyBuff);
-            poVerifyBuff = NULL;
+            poVerifyBuff = nullptr;
          }
 
          for (j=0; j<oImageFileCount; j++)
             free (poImageFilenameArr[j]);
          free (poImageFilenameArr);
 
-         poFile = NULL;
+         poFile = nullptr;
          return NO_ERROR;
       }
 
@@ -712,7 +713,7 @@ class t_OutputFileEWF: public t_OutputFile
 
       bool Opened (void)
       {
-         return (poFile != NULL);
+         return (poFile != nullptr);
       }
 
    private:
@@ -740,10 +741,10 @@ class t_OutputFileAAFF: public t_OutputFile
    public:
       t_OutputFileAAFF (t_ThreadWrite *pThreadWrite) :
          t_OutputFile           (pThreadWrite),
-         poFile                 (NULL ),
-         poAcquisition          (NULL ),
-         poDevice               (NULL ),
-         poVerifyBuff           (NULL ),
+         poFile                 (nullptr),
+         poAcquisition          (nullptr),
+         poDevice               (nullptr),
+         poVerifyBuff           (nullptr),
          oHasCompressionThreads (false),
          oVerification          (false)
       {
@@ -866,7 +867,7 @@ class t_OutputFileAAFF: public t_OutputFile
          if (*pPos == 0)
          {
             poVerifyBuff = UTIL_MEM_ALLOC (poDevice->FifoBlockSize);
-            if (poVerifyBuff == NULL)
+            if (poVerifyBuff == nullptr)
                CHK (ERROR_THREADWRITE_MALLOC_FAILED);
          }
          rc = AaffReadNextPage (poFile, (unsigned char *) poVerifyBuff, &DataLen, &ImageFilename, &MD5Digest, &MD5Valid);
@@ -899,7 +900,7 @@ class t_OutputFileAAFF: public t_OutputFile
          QList<quint64> BadSectors;
          int            Seconds;
 
-         if (poFile == NULL)
+         if (poFile == nullptr)
             CHK (ERROR_THREADWRITE_NOT_OPENED)
 
          if (oVerification)
@@ -908,7 +909,7 @@ class t_OutputFileAAFF: public t_OutputFile
             if (poVerifyBuff)
             {
                UTIL_MEM_FREE (poVerifyBuff);
-               poVerifyBuff = NULL;
+               poVerifyBuff = nullptr;
             }
          }
          else
@@ -919,7 +920,7 @@ class t_OutputFileAAFF: public t_OutputFile
             CHK (AaffClose (&poFile, BadSectors.count(), (unsigned char*)&poDevice->MD5Digest, (unsigned char*)&poDevice->SHA1Digest, (unsigned char*)&poDevice->SHA256Digest, Seconds))
          }
 
-         poFile = NULL;
+         poFile = nullptr;
 
          return NO_ERROR;
       }
@@ -932,7 +933,7 @@ class t_OutputFileAAFF: public t_OutputFile
 
       bool Opened (void)
       {
-         return (poFile != NULL);
+         return (poFile != nullptr);
       }
 
    private:
@@ -953,10 +954,10 @@ class t_OutputFileAEWF: public t_OutputFile
    public:
       t_OutputFileAEWF (t_ThreadWrite *pThreadWrite) :
          t_OutputFile           (pThreadWrite),
-         poFile                 (NULL ),
-         poAcquisition          (NULL ),
-         poDevice               (NULL ),
-         poVerifyBuff           (NULL ),
+         poFile                 (nullptr),
+         poAcquisition          (nullptr),
+         poDevice               (nullptr),
+         poVerifyBuff           (nullptr),
           oHasCompressionThreads(false),
           oVerification         (false)
       {
@@ -970,10 +971,11 @@ class t_OutputFileAEWF: public t_OutputFile
 
       APIRET Open (t_pAcquisition pAcquisition, bool Verify)
       {
-         t_pAewf pFile = NULL;
+         t_pAewf pFile = nullptr;
          QString  FileName;
          QString  GuymagerVersion;
          QString  Uname;
+         APIRET   rc;
 
          poAcquisition = pAcquisition;
          poDevice      = pAcquisition->pDevice;
@@ -983,7 +985,12 @@ class t_OutputFileAEWF: public t_OutputFile
          FileName = poAcquisition->ImagePath + pAcquisition->ImageFilename;
          if (oVerification)
          {
-            CHK (AewfOpen (&pFile, QSTR_TO_PSZ(FileName)))
+            rc = AewfOpen (&pFile, QSTR_TO_PSZ(FileName));
+            if (rc)
+            {
+               LOG_INFO ("[%s] Opening AEWF image for verification failed: %s", QSTR_TO_PSZ (poDevice->LinuxDevice), ToolErrorMessage (rc))
+               return ERROR_THREADWRITE_OPEN_FAILED;
+            }
          }
          else
          {
@@ -994,13 +1001,19 @@ class t_OutputFileAEWF: public t_OutputFile
                GuymagerVersion = GuymagerVersion.left (THREADWRITE_ENCASE_MAXLEN_IMAGERVERSION);
                Uname           = Uname          .left (THREADWRITE_ENCASE_MAXLEN_OSVERSION    );
             }
-            CHK (AewfOpen (&pFile, QSTR_TO_PSZ(FileName), poDevice->Size, pAcquisition->SplitFileSize, poDevice->FifoBlockSize, poDevice->SectorSize,
+            rc = AewfOpen (&pFile, QSTR_TO_PSZ(FileName), poDevice->Size, pAcquisition->SplitFileSize, poDevice->FifoBlockSize, poDevice->SectorSize,
                                    poDevice->Removable ? AEWF_MEDIATYPE_REMOVABLE : AEWF_MEDIATYPE_FIXED,
                                    AEWF_MEDIAFLAGS_PHYSICAL,
                                    pAcquisition->Description, pAcquisition->CaseNumber, pAcquisition->EvidenceNumber,
-                                   pAcquisition->Examiner   , pAcquisition->Notes     , poDevice->Model                     ,
-                                   poDevice->SerialNumber   , GuymagerVersion         , Uname))
+                                   pAcquisition->Examiner   , pAcquisition->Notes     , poDevice->Model             ,
+                                   poDevice->SerialNumber   , GuymagerVersion         , Uname);
+            if (rc)
+            {
+               LOG_INFO ("[%s] Opening AEWF image for writing failed: %s", QSTR_TO_PSZ (poDevice->LinuxDevice), ToolErrorMessage (rc))
+               return ERROR_THREADWRITE_OPEN_FAILED;
+            }
          }
+
          poFile = pFile; // Only set poFile at the very end, so the CompressionThreads won't use it until everything is initialised
          return NO_ERROR;
       }
@@ -1078,7 +1091,7 @@ class t_OutputFileAEWF: public t_OutputFile
          if (*pPos == 0)
          {
             poVerifyBuff = UTIL_MEM_ALLOC (poDevice->FifoAllocBlockSize);
-            if (poVerifyBuff == NULL)
+            if (poVerifyBuff == nullptr)
                CHK (ERROR_THREADWRITE_MALLOC_FAILED);
          }
          CHK (ProcessUnit (pHashContextMD5, pHashContextSHA1, pHashContextSHA256, ImageFileHashList, pPos, &Finished))
@@ -1095,7 +1108,7 @@ class t_OutputFileAEWF: public t_OutputFile
       {
          QList<quint64> BadSectors;
 
-         if (poFile == NULL)
+         if (poFile == nullptr)
             CHK (ERROR_THREADWRITE_NOT_OPENED)
 
          if (oVerification)
@@ -1107,7 +1120,7 @@ class t_OutputFileAEWF: public t_OutputFile
             CHK (poDevice->GetBadSectors (BadSectors, false))
             CHK (AewfClose (&poFile, BadSectors, (unsigned char*)&poDevice->MD5Digest, (unsigned char*)&poDevice->SHA1Digest, (unsigned char*)&poDevice->SHA256Digest))
          }
-         poFile = NULL;
+         poFile = nullptr;
 
          return NO_ERROR;
       }
@@ -1120,7 +1133,7 @@ class t_OutputFileAEWF: public t_OutputFile
 
       bool Opened (void)
       {
-         return (poFile != NULL);
+         return (poFile != nullptr);
       }
 
    private:
@@ -1141,9 +1154,9 @@ class t_ThreadWriteLocal
 {
    public:
       t_ThreadWriteLocal (void) :
-         pOutputFile        (NULL),
-         pSlowDownRequest   (NULL),
-         pAcquisition       (NULL),
+         pOutputFile        (nullptr),
+         pSlowDownRequest   (nullptr),
+         pAcquisition       (nullptr),
          FileHandleRequests (0)
       {}
 
@@ -1163,7 +1176,7 @@ t_ThreadWrite::t_ThreadWrite(void)
 } //lint !e1401 not initialised
 
 t_ThreadWrite::t_ThreadWrite (t_pAcquisition pAcquisition, t_pFifo *ppFifo, bool *pSlowDownRequest)
-   :pOwn(NULL)
+   :pOwn(nullptr)
 {
    static bool Initialised = false;
 
@@ -1188,7 +1201,7 @@ t_ThreadWrite::t_ThreadWrite (t_pAcquisition pAcquisition, t_pFifo *ppFifo, bool
    pOwn = new t_ThreadWriteLocal;
    pOwn->pAcquisition       = pAcquisition;
    pOwn->ppFifo             = ppFifo;
-   pOwn->pOutputFile        = NULL;
+   pOwn->pOutputFile        = nullptr;
    pOwn->pSlowDownRequest   = pSlowDownRequest;
    pOwn->FileHandleRequests = 0;
 
@@ -1219,9 +1232,9 @@ static APIRET ThreadWriteDebugCheckLibewfData (t_pFifoBlock pFifoBlock)
       UncompressedSize = pFifoBlock->DataSize + 4096; // DataSize should be enough for the uncompression buffer, as the uncompressed data originally had that
                                                       // size, but as this fn is used for debugging and we do not know what the bug might be, we add 4K for safety
       pBufferUncompressed = (unsigned char *) UTIL_MEM_ALLOC (UncompressedSize);
-      if (pBufferUncompressed == NULL)
+      if (pBufferUncompressed == nullptr)
       {
-         LOG_ERROR ("malloc returned NULL")
+         LOG_ERROR ("malloc returned nullptr")
          CHK_EXIT (1967)
       }
       zrc = uncompress ((Bytef*)pBufferUncompressed, &UncompressedSize, pFifoBlock->Buffer, pFifoBlock->EwfDataSize);
@@ -1270,7 +1283,7 @@ void t_ThreadWrite::run (void)
    t_pDevice      pDevice;
    t_pFifo        pFifo;
    t_pFifoBlock   pFifoBlock;
-   t_OutputFile  *pOutputFile= NULL;
+   t_OutputFile  *pOutputFile= nullptr;
    bool            Finished  = false;
    bool            FileHandleReleased;
    quint64         Blocks    = 0;
@@ -1332,7 +1345,7 @@ void t_ThreadWrite::run (void)
 //         t_Fifo::LogBlock (pDevice->pFifoMemory, pFifoBlock, 'w');
          if (pFifoBlock->Nr != Blocks)
          {
-            LOG_ERROR ("[%s] Fifo block number out of sequence. Expected: %Ld Received: %Ld", QSTR_TO_PSZ (pDevice->LinuxDevice), Blocks, pFifoBlock->Nr)
+            LOG_ERROR ("[%s] Fifo block number out of sequence. Expected: %lld Received: %lld", QSTR_TO_PSZ (pDevice->LinuxDevice), Blocks, pFifoBlock->Nr)
 //            t_Fifo::LogBlock (pDevice->pFifoMemory, pFifoBlock, 'e');
             CHK_EXIT (ERROR_THREADWRITE_OUT_OF_SEQUENCE_BLOCK)
          }
@@ -1410,9 +1423,9 @@ void t_ThreadWrite::run (void)
       t_pHashContextSHA256 pHashContextSHA256 = &HashContextSHA256;
       quint64               Pos = 0;
 
-      if (pAcquisition->CalcMD5)    CHK_EXIT (HashMD5Init    (pHashContextMD5   ))  else pHashContextMD5    = NULL;
-      if (pAcquisition->CalcSHA1)   CHK_EXIT (HashSHA1Init   (pHashContextSHA1  ))  else pHashContextSHA1   = NULL;
-      if (pAcquisition->CalcSHA256) CHK_EXIT (HashSHA256Init (pHashContextSHA256))  else pHashContextSHA256 = NULL;
+      if (pAcquisition->CalcMD5)    CHK_EXIT (HashMD5Init    (pHashContextMD5   ))  else pHashContextMD5    = nullptr;
+      if (pAcquisition->CalcSHA1)   CHK_EXIT (HashSHA1Init   (pHashContextSHA1  ))  else pHashContextSHA1   = nullptr;
+      if (pAcquisition->CalcSHA256) CHK_EXIT (HashSHA256Init (pHashContextSHA256))  else pHashContextSHA256 = nullptr;
 
       LOG_INFO ("[%s] Reopening image file for verification", QSTR_TO_PSZ (pDevice->LinuxDevice))
       CHK_EXIT (SetDebugMessage ("pOutputFile->Open verification"))
@@ -1464,7 +1477,7 @@ void t_ThreadWrite::run (void)
    // Finish
    // ------
    delete pOwn->pOutputFile;
-   pOwn->pOutputFile = NULL;
+   pOwn->pOutputFile = nullptr;
 
    if (pDevice->Error.Abort(pAcquisition->Instance) && pDevice->DeleteAfterAbort)
    {
@@ -1472,7 +1485,7 @@ void t_ThreadWrite::run (void)
       CHK_EXIT (DeleteImageFiles (true))
    }
 
-   LOG_INFO ("[%s] Write thread %d exits now (%Ld blocks processed, %Ld bytes written to output file)", QSTR_TO_PSZ (pDevice->LinuxDevice), pAcquisition->Instance, Blocks, pAcquisition->CurrentWritePos.Get())
+   LOG_INFO ("[%s] Write thread %d exits now (%lld blocks processed, %lld bytes written to output file)", QSTR_TO_PSZ (pDevice->LinuxDevice), pAcquisition->Instance, Blocks, pAcquisition->CurrentWritePos.Get())
    CHK_EXIT (SetDebugMessage ("Exit run function"))
 }
 //lint -restore
@@ -1532,7 +1545,7 @@ void t_ThreadWrite::SlotFinished (void)
 
 APIRET t_ThreadWrite::GetpFileHandle0 (void **ppHandle)
 {
-   *ppHandle = NULL;
+   *ppHandle = nullptr;
 
    if (!isRunning())       return ERROR_THREADWRITE_HANDLE_NOT_YET_AVAILABLE;   // This never happens, as the threads are all created together and only started after that
    if (!pOwn->pOutputFile) return ERROR_THREADWRITE_HANDLE_NOT_YET_AVAILABLE;
@@ -1549,7 +1562,7 @@ APIRET t_ThreadWrite::GetpFileHandle (void **ppHandle)
    APIRET          rc;
    t_pAcquisition pAcquisition = pOwn->pAcquisition;
 
-   *ppHandle = NULL;
+   *ppHandle = nullptr;
    do
    {
       if (pAcquisition->pDevice->Error.Abort(pAcquisition->Instance))  // May happen, for example, if the write thread wasn't able to open the destination file.
@@ -1562,7 +1575,7 @@ APIRET t_ThreadWrite::GetpFileHandle (void **ppHandle)
          pOwn->SemHandle.unlock();
          CHK (rc)
       }
-      if (*ppHandle == NULL)
+      if (*ppHandle == nullptr)
       {
          pOwn->SemHandle.unlock();
 
@@ -1572,7 +1585,7 @@ APIRET t_ThreadWrite::GetpFileHandle (void **ppHandle)
 
          msleep (THREADWRITE_WAIT_FOR_HANDLE_GRANULARITY);
       }
-   } while (*ppHandle == NULL);
+   } while (*ppHandle == nullptr);
 
    pOwn->FileHandleRequests++;
    pOwn->SemHandle.unlock();
